note 61837 deleted from function.array-merge by bjori

From: Date: Mon, 24 Apr 2006 20:27:25 +0000
Subject: note 61837 deleted from function.array-merge by bjori
References: 1  Groups: php.notes 
Request: Send a blank email to php-notes+get-109607@lists.php.net to get a copy of this message
Note Submitter: Johannes ---- Beware, array_merge() is insanely slow! Just converting this: $this->content = array_merge($this->content,$new_content); to this: foreach ($new_content as $piece) { $this->content[] = $piece; } decreased my scripts' execution time from 1500ms to 58ms.

« previous php.notes (#109607) next »